@@ -29,7 +29,7 @@
 #include <string.h>
 #include <pwd.h>
 #include <assert.h>
-#if defined(__FreeBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 #include <fstab.h>
 #elif defined(__linux__)
 #include <mntent.h>
@@ -49,7 +49,6 @@
 #define EVP_MAX_BLOCK_LENGTH 0  /* FIXME: this is ugly, but needed */
 #endif
 #include <sys/types.h>
-#include <sys/resource.h>
 #include <sys/wait.h>
 #include <stdlib.h>
 #include <limits.h>
@@ -115,6 +114,7 @@ static void run_lsof(const struct config_t *const config,
 /*
  * PRE:    config->volume[vol].type is a mount type (LCLMOUNT, SMBMOUNT, ...)
  *         sizeof(mntpt) >= PATH_MAX + 1
+ *         vinfo is a valid struct fmt_ptrn_t
  * POST:   mntpt contains:
  *           config->volume[vol].mountpoint if config->volume[vol].volume is
  *             already mounted there
@@ -124,14 +124,15 @@ static void run_lsof(const struct config_t *const config,
  *         errors are logged
  */
 static int already_mounted(const struct config_t *const config,
-			   const unsigned int vol, char *const mntpt)
+			   const unsigned int vol, char *const mntpt,
+			   fmt_ptrn_t *vinfo)
 {
 	char match[PATH_MAX + 1];
 	int mounted = 0;
 #if defined(__linux__)
 	FILE *mtab;
 	struct mntent *mtab_record;
-#elif defined(__FreeBSD__) || defined(__OpenBSD__)
+#elif defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 	int fds[2];
 	pid_t pid;
 #endif
@@ -225,7 +226,7 @@ static int already_mounted(const struct config_t *const config,
 	}
 	fclose(mtab);
 	return mounted;
-#elif defined(__FreeBSD__) || defined(__OpenBSD__)
+#elif defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 	{
 		FILE *fp;
 		GError *err = NULL;
@@ -530,13 +531,13 @@ do_losetup(struct config_t *config, const unsigned int vol,
 	w4rn("pam_mount: umount errors (should be empty):\n");
 	log_output(cstderr);
 	CLOSE(cstderr);
-	w4rn("pam_mount: %s\n", "waiting for umount");
+	w4rn("pam_mount: %s\n", "waiting for losetup");
 	if (waitpid(pid, &child_exit, 0) == -1) {
 		l0g("pam_mount: error waiting for child\n");
 		ret = 0;
 		goto _return;
 	} else {
-		/* pass on through the result from the umount process */
+		/* pass on through the result from the losetup process */
 		ret = !WEXITSTATUS(child_exit);
 	}
       _return:
@@ -680,7 +681,7 @@ do_mount(struct config_t *config, const unsigned int vol,
 	assert(password);
 
 	/* FIXME: This is a little ugly, especially check for != LCLMOUNT */
-	if ((mount_again = already_mounted(config, vol, prev_mntpt))) {
+	if ((mount_again = already_mounted(config, vol, prev_mntpt, vinfo))) {
 		if (mount_again == -1) {
 			l0g("pam_mount: could not determine if %s is already mounted, failing\n", config->volume[vol].volume);
 			return 0;
@@ -716,7 +717,6 @@ do_mount(struct config_t *config, const unsigned int vol,
 			l0g("pam_mount: mntagain not defined in pam_mount.conf\n");
 			return 0;
 		}
-#if defined(__linux__)
 		/* FIXME: NEW */
 		fmt_ptrn_update_kv(vinfo, "PREVMNTPT", prev_mntpt);
 		for (i = 0; config->command[i][MNTAGAIN]; i++)
@@ -731,12 +731,6 @@ do_mount(struct config_t *config, const unsigned int vol,
 			g_error_free(err);
 			return 0;
 		}
-#else
-		/* FIXME */
-		l0g("pam_mount: %s\n",
-		    "multiple mounts of same volume not implemented on arch.");
-		return 0;
-#endif
 	} else {
 		GError *err = NULL;
 		if (!config->command[0][config->volume[vol].type]) {
@@ -762,7 +756,7 @@ do_mount(struct config_t *config, const unsigned int vol,
 			/* _password is an ASCII string in this case -- we'll treat its
 			 * MAX_PAR + EVP_MAX_BLOCK_LENGTH size as the standard string 
 			 * MAX_PAR + 1 in this case */
-			strncpy(_password, password, MAX_PAR);
+			strncpy((char *) _password, password, MAX_PAR);
 			_password[MAX_PAR] = 0x00;
 			_password_len = strlen(password);
 		}
